package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: May 17, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Pool of work coroutines struct
func NewPool(workers, queueSize int) *Pool
New goroutine pool with workers counts and capacity
Gracefully close the pool
Task should be a function receive nothing and return nothing
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.